@@ -1,6 +1,6 @@
 package CatalystX::Controller::Role::PermissionCheck;
 BEGIN {
-  $CatalystX::Controller::Role::PermissionCheck::VERSION = '0.02';
+  $CatalystX::Controller::Role::PermissionCheck::VERSION = '0.03';
 }
 
 use Moose::Role;
@@ -36,7 +36,7 @@ has 'allow_by_default' => (
 
 sub fetch_permissions {
     my ( $self, $c ) = @_;
-    return $c->stash->{context}->{permissions};
+    return $c->stash->{context}->{permissions} || {};
 }
 
 
@@ -94,7 +94,7 @@ CatalystX::Controller::Role::PermissionCheck - Provides an opinionated method fo
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -169,8 +169,9 @@ the permissions hash.
 
 =head2 fetch_permissions
 
-Retrieve a hashref of permissions. This may be overridden to allow alternate sources
-of permissions, but by default it looks in $c->stash->{context}->{permissions}.
+Retrieve a hashref of permissions. This may be overridden to allow alternate
+sources of permissions, but by default it looks in
+$c->stash->{context}->{permissions}.
 
 =head2 setup
 
